@@ -22,6 +22,8 @@ import java.util.SortedSet;
 public abstract class ServerDescriptorImpl extends DescriptorImpl
     implements ServerDescriptor {
 
+  private static final long serialVersionUID = 5240701284736998121L;
+
   private static final Set<Key> atMostOnce = EnumSet.of(
       Key.IDENTITY_ED25519, Key.MASTER_KEY_ED25519, Key.PLATFORM, Key.PROTO,
       Key.FINGERPRINT, Key.HIBERNATING, Key.UPTIME, Key.CONTACT, Key.FAMILY,
@@ -31,7 +33,7 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
       Key.IPV6_POLICY, Key.NTOR_ONION_KEY, Key.ONION_KEY_CROSSCERT,
       Key.NTOR_ONION_KEY_CROSSCERT, Key.TUNNELLED_DIR_SERVER,
       Key.ROUTER_SIG_ED25519, Key.ROUTER_SIGNATURE, Key.ROUTER_DIGEST_SHA256,
-      Key.ROUTER_DIGEST);
+      Key.ROUTER_DIGEST, Key.BRIDGE_DISTRIBUTION_REQUEST);
 
   private static final Set<Key> exactlyOnce = EnumSet.of(
       Key.ROUTER, Key.BANDWIDTH, Key.PUBLISHED);
@@ -113,6 +115,9 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
         case CONTACT:
           this.parseContactLine(lineNoOpt);
           break;
+        case BRIDGE_DISTRIBUTION_REQUEST:
+          this.parseBridgeDistributionRequestLine(line, partsNoOpt);
+          break;
         case FAMILY:
           this.parseFamilyLine(line, partsNoOpt);
           break;
@@ -394,6 +399,14 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
     }
   }
 
+  private void parseBridgeDistributionRequestLine(String line,
+      String[] partsNoOpt) throws DescriptorParseException {
+    if (partsNoOpt.length < 2) {
+      throw new DescriptorParseException("Illegal line '" + line + "'.");
+    }
+    this.bridgeDistributionRequest = partsNoOpt[1];
+  }
+
   private void parseFamilyLine(String line,
       String[] partsNoOpt) throws DescriptorParseException {
     String[] familyEntries = new String[partsNoOpt.length - 1];
@@ -790,6 +803,13 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
     return this.contact;
   }
 
+  private String bridgeDistributionRequest = null;
+
+  @Override
+  public String getBridgeDistributionRequest() {
+    return this.bridgeDistributionRequest;
+  }
+
   private String[] familyEntries;
 
   @Override
